@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2009  Stephane Pion
+   Copyright (C) 2009,2011  Stephane Pion
    This file is part of Intifada.
 
     Intifada is free software: you can redistribute it and/or modify
@@ -64,7 +64,7 @@ int intifada::Part_Configuration::operator()(intifada::Repetitive_Length_Data_Fi
 }
 
 intifada::Current::Current_Iterator::Current_Iterator():
-								  current_field_(NULL)
+												  current_field_(NULL)
 ,name_()
 ,type_()
 ,start_()
@@ -119,12 +119,12 @@ intifada::Current::Current_Iterator::operator()(Record*){return 0;}
 
 
 intifada::Current::Current():
-								  fixed_(NULL),
-								  extended_(NULL),
-								  repetitive_(NULL),
-								  compound_(NULL),
-								  handler_(NULL),
-								  current_(NONE)
+												  fixed_(NULL),
+												  extended_(NULL),
+												  repetitive_(NULL),
+												  compound_(NULL),
+												  handler_(NULL),
+												  current_(NONE)
 {}
 
 void
@@ -221,17 +221,17 @@ throw(std::domain_error)
 	}
 }
 
-intifada::Configuration_Reader::Configuration_Reader():
-								  current_condition_(NULL),
-								  current_item_longname_(),
-								  current_item_(),
-								  // current_part_(),
-								  current_forcepresence_("false"),
-								  current_family_(),
-								  rep_(NULL),
-								  current_(),
-								  handler_(NULL),
-								  node_stack_()
+intifada::Configuration_Reader::Configuration_Reader()
+:current_condition_(NULL),
+ current_item_longname_(),
+ current_item_(),
+ // current_part_(),
+ current_forcepresence_("false"),
+ current_family_(),
+ rep_(NULL),
+ current_(),
+ handler_(NULL),
+ node_stack_()
 {
 	handler_=new Part_Configuration;
 	current_.register_handler(handler_);
@@ -242,6 +242,11 @@ intifada::Configuration_Reader::~Configuration_Reader()
 	delete handler_;
 }
 
+int intifada::Configuration_Reader::parse()
+{
+	return this->parse(intifada::Record_Repository::instance());
+}
+
 void
 intifada::Configuration_Reader::set_repository(Record_Repository*r)
 {
@@ -270,7 +275,8 @@ intifada::Configuration_Reader::create_record(
 )
 {
 	r=new intifada::Record;
-	clog("Configuration_Reader") << "create_record (0x << " << std::hex << r << std::endl;
+	clog("Configuration_Reader") << "create_record (0x << " << std::hex << r << ")" << std::endl;
+
 	r->set_identity(name,id,category);
 	rep_->insert(r,name,id,category);
 }
@@ -323,11 +329,11 @@ intifada::Configuration_Reader::create_uap(
 		const std::string& result
 )
 {
-	clog("Configuration_Reader") << "create_uap:if=" << func << " value=" << result << std::endl;
-
 	if(func.empty()!=true){
+		clog("Configuration_Reader") << "create_uap:if=" << func << " value=" << result << std::endl;
 		current_condition_=new intifada::Condition(func,result);
 	}else{
+		clog("Configuration_Reader") << "create_uap" << std::endl;
 		current_condition_=NULL;
 	}
 }
@@ -340,10 +346,7 @@ intifada::Configuration_Reader::create_frn(
 )
 {
 	Path_Name lastpartitem=Path_Name(item.get_back());
-	clog("Configuration_Reader")
-	<< "create_frn " << std::dec << int(frn)
-	<< " " << lastpartitem << " (for 0x" << std::hex << r << ")"
-	<< std::endl;
+	clog("Configuration_Reader") << "create_frn " << std::dec << int(frn) << " " << lastpartitem << " (for 0x" << std::hex << r << ")"<< std::endl;
 	if(current_condition_!=NULL){
 		r->insert(frn,lastpartitem,current_condition_);
 	}else{
@@ -428,9 +431,9 @@ int intifada::Configuration_Reader::handle_parts(
 }
 
 void intifada::Configuration_Reader::set_type_property(const std::string& prop,const std::string& val)throw(std::domain_error)
-                								{
+                												{
 	current_.set_type_property(prop,val);
-                								}
+                												}
 
 void intifada::Configuration_Reader::set_item_property(
 		const std::string& name,
