@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2009  Stephane Pion
+   Copyright (C) 2009,2011  Stephane Pion
    This file is part of Intifada.
 
     Intifada is free software: you can redistribute it and/or modify
@@ -31,7 +31,9 @@ ti_(NULL)
 ,start_position_(0)
 ,size_(0)
 ,cached_(false)
-{}
+{
+	clog("Memory_Allocation") << "0x" << this << ":ctor Data_Field_Characteristics" << std::endl;
+}
 
 intifada::Data_Field_Characteristics::Data_Field_Characteristics(const Data_Field_Characteristics&rhs):
 				  ti_()
@@ -64,7 +66,7 @@ intifada::Data_Field_Characteristics::operator=(const Data_Field_Characteristics
 
 intifada::Data_Field_Characteristics::~Data_Field_Characteristics()
 {
-	clog("Memory_Allocation") << "0x" << this << ":release Data_Field_Characteristics" << std::endl;
+	clog("Memory_Allocation") << "0x" << this << ":dtor Data_Field_Characteristics" << std::endl;
 	if(ti_!=NULL)
 	{
 		delete ti_;
