@@ -58,8 +58,8 @@ const uint8_t intifada::String_Type::icao2ascii[]=
 		,0x30,0x31,0x32,0x33,0x34,0x35,0x36,0x37,0x38,0x39,0x00,0x00,0x00,0x00,0x00,0x00
 };
 
-intifada::String_Type::String_Type():
-		  inherited()
+intifada::String_Type::String_Type()
+:inherited()
 ,code_()
 ,value_()
 ,base_value_()
@@ -67,15 +67,15 @@ intifada::String_Type::String_Type():
 ,stream_character_size_(8)
 ,keep_code_(false)
 {
-	this->set_type_id();
+	this->set_type_id("String_Type");
 	this->register_property("stream_coding",stream_coding_);
 	this->register_property("stream_character_size",stream_character_size_);
 	this->register_property("keep_code",keep_code_);
 
 }
 
-intifada::String_Type::String_Type(const std::string& rhs):
-		  inherited()
+intifada::String_Type::String_Type(const std::string& rhs)
+:inherited()
 ,code_()
 ,value_()
 ,base_value_()
@@ -83,38 +83,45 @@ intifada::String_Type::String_Type(const std::string& rhs):
 ,stream_character_size_(8)
 ,keep_code_(false)
 {
-	this->set_type_id();
+	this->set_type_id("String_Type");
 	this->register_property("stream_coding",stream_coding_);
 	this->register_property("stream_character_size",stream_character_size_);
 	this->register_property("keep_code",keep_code_);
 	this->set_from_string(rhs);
 }
 
-intifada::String_Type::String_Type(const String_Type& rhs):
-		  inherited(rhs)
+intifada::String_Type::String_Type(const String_Type& rhs)
+:inherited(rhs)
 ,code_(rhs.code_)
 ,value_(rhs.value_)
 ,base_value_(rhs.base_value_)
-,stream_coding_()
-,stream_character_size_()
-,keep_code_()
+,stream_coding_(rhs.stream_coding_)
+,stream_character_size_(rhs.stream_character_size_)
+,keep_code_(rhs.keep_code_)
 {
 	this->relink_property("stream_coding",stream_coding_);
 	this->relink_property("stream_character_size",stream_character_size_);
 	this->relink_property("keep_code",keep_code_);
 
 }
-intifada::String_Type::String_Type(const Type&rhs):
-		  inherited(dynamic_cast<const String_Type&>(rhs))
-{}
-
-std::string intifada::String_Type::get_type_id()const
+intifada::String_Type::String_Type(const Type&rhs)
+:inherited(rhs)
 {
-	return "String_Type";
+	const String_Type& rhs_string=dynamic_cast<const String_Type&>(rhs);
+	code_=rhs_string.code_;
+	value_=rhs_string.value_;
+	base_value_=rhs_string.base_value_;
+	stream_coding_=rhs_string.stream_coding_;
+	stream_character_size_=rhs_string.stream_character_size_;
+	keep_code_=rhs_string.keep_code_;
+	this->relink_property("stream_coding",stream_coding_);
+	this->relink_property("stream_character_size",stream_character_size_);
+	this->relink_property("keep_code",keep_code_);
 }
 
 intifada::String_Type& intifada::String_Type::operator=(const Type&rhs)
 {
+
 	return this->operator=(dynamic_cast<const String_Type&>(rhs));
 }
 
@@ -159,14 +166,15 @@ ssize_t intifada::String_Type::get_size()const
 	return -1;
 }
 
-bool intifada::String_Type::operator==(const std::string& rhs)const
-		{
-	return value_==rhs;
-		}
+bool
+intifada::String_Type::operator==(const std::string& rhs)const
+{
+	return trim_trailing_spaces(value_)==rhs;
+}
 
 std::string intifada::String_Type::get_to_string()const
 {
-	return value_;
+	return trim_trailing_spaces(value_);
 }
 
 int intifada::String_Type::set_from_string(const std::string& v)
@@ -177,9 +185,9 @@ int intifada::String_Type::set_from_string(const std::string& v)
 
 void intifada::String_Type::set_from_stream(Stream::const_reverse_iterator b,int start,int size)
 {
-	clog("String_Type")
-    		  << "set_from_stream("<< this << ":"
-    		  << stream_coding_.string_value() <<"):" << std::dec << start << "," << size << std::endl;
+	clog("String_Type") \
+			<< "set_from_stream("<< this << ":"
+			<< stream_coding_.string_value() <<"):" << std::dec << start << "," << size << std::endl;
 
 	int char_start=start-1;
 	int char_total=size/static_cast<int>(stream_character_size_);
@@ -241,8 +249,9 @@ intifada::String_Type* intifada::String_Type::clone()const
 	return new String_Type(*this);
 }
 
-void intifada::String_Type::set_property(const std::string& prop,const std::string& val)throw(std::domain_error)
-    		{
+void
+intifada::String_Type::set_property(const std::string& prop,const std::string& val)throw(std::domain_error)
+{
 	this->Properties::set_property(prop,val);
 	if(prop=="stream_coding"){
 		if(val=="icao"){
@@ -253,8 +262,13 @@ void intifada::String_Type::set_property(const std::string& prop,const std::stri
 			code_=ASCII;
 		}
 	}
-    		}
-
+}
+std::string intifada::String_Type::trim_trailing_spaces(const std::string& v)const
+{
+	// to strip trailling spaces
+	const std::string::size_type size = v.find_last_not_of(" ") + 1;
+	return v.substr(0, size);
+}
 std::ostream& operator<< (std::ostream& os,intifada::String_Type& str)
 {
 	os << str.get_to_string();
