@@ -31,8 +31,8 @@ intifada::Type::Type()
 ,_unit_converter(NULL)
 {}
 
-intifada::Type::Type(const Type&rhs):
-		  inherited(rhs)
+intifada::Type::Type(const Type&rhs)
+:inherited(rhs)
 ,type_name_(rhs.type_name_)
 {
 	if(rhs._unit_converter!=NULL)
@@ -52,7 +52,7 @@ intifada::Type& intifada::Type::operator=(const Type&rhs)
 	if(this != &rhs)
 	{
 		inherited::operator=(rhs);
-		type_name_=rhs.type_name_;
+		// type_name_=rhs.type_name_;
 		if(rhs._unit_converter!=NULL)
 			_unit_converter=rhs._unit_converter->clone();
 		else
@@ -67,9 +67,9 @@ intifada::Type::~Type()
 }
 
 /// Call this to setup type identification
-void intifada::Type::set_type_id()
+void intifada::Type::set_type_id(const std::string& v)
 {
-	type_name_=this->get_type_id();
+	type_name_=v;
 }
 
 /// Put asterix stream in a stream byte
